import os
from flask import Flask


def create_app(test_config=None):
    app = Flask(__name__, instance_relative_config=True)
    app.config.from_mapping(
        SECRET_KEY='dev',
        SQLALCHEMY_DATABASE_URI="sqlite:///" + os.path.abspath(
            os.path.join(app.instance_path, 'db.sqlite')
        ),
        UPLOAD_FOLDER=os.path.abspath(os.path.join(
            app.instance_path, 'uploads'
        )),
        SQLALCHEMY_TRACK_MODIFICATIONS=False
    )

    if test_config is None:
        # instance config for prod+dev
        app.config.from_pyfile('config.py', silent=True)
    else:
        # config for test
        app.config.from_mapping(test_config)

    # create the instance folder
    try:
        os.makedirs(app.instance_path)
    except OSError:
        pass

    from .db import db, migrate
    db.init_app(app)
    migrate.init_app(app, db)

    from . import auth, channel, nginx, cytube
    app.register_blueprint(auth.bp)
    app.register_blueprint(channel.bp, url_prefix="/channel")
    app.register_blueprint(nginx.bp, url_prefix="/nginx")
    app.register_blueprint(cytube.bp, url_prefix="/streams")

    app.add_url_rule("/.emotes/<path:filename>", "serve_emote",
                     channel.serve_emote)

    return app
