from sqlalchemy import MetaData
from flask_sqlalchemy import SQLAlchemy
from flask_migrate import Migrate

db = SQLAlchemy()
convention = {
    "ix": 'ix_%(column_0_label)s',
    "uq": "uq_%(table_name)s_%(column_0_name)s",
    "ck": "ck_%(table_name)s_%(constraint_name)s",
    "fk": "fk_%(table_name)s_%(column_0_name)s_%(referred_table_name)s",
    "pk": "pk_%(table_name)s"
}

metadata = MetaData(naming_convention=convention)
db = SQLAlchemy(metadata=metadata)
migrate = Migrate()


class Channel(db.Model):

    id = db.Column(db.Integer, primary_key=True)

    username = db.Column(db.String(32), nullable=False, unique=True)
    # PBKDF2. Werkzeug returns a 94 char string.
    password = db.Column(db.String(94), nullable=False)

    # UUID
    stream_key = db.Column(db.String(36), nullable=False, unique=True)
    # UUID
    current_stream_id = db.Column(db.String(36), nullable=True)
    live = db.Column(db.Boolean(name="live"), nullable=False, default=False)

    stream_title = db.Column(db.String(120), nullable=False,
                             default="Watching possums")


class Emote(db.Model):

    id = db.Column(db.Integer, primary_key=True)

    channel_id = db.Column(db.Integer, db.ForeignKey("channel.id"),
                           nullable=False)
    channel = db.relationship("Channel", lazy=True, backref=db.backref(
        "emotes", lazy=False
    ))

    emote_name = db.Column(db.String(64), nullable=False, unique=True)
    emote_url = db.Column(db.String(64), nullable=False)
