"""Nginx internal views."""
import functools
import uuid

from flask import current_app, request, Blueprint, redirect

from .db import db, Channel


bp = Blueprint("nginx", __name__)


def check_stream_secret(view):
    @functools.wraps(view)
    def wrapped_view(*args, **kwargs):
        if request.args.get("secret") != current_app.config["NGINX_SECRET"]:
            return "", 400
        return view(*args, **kwargs)
    return wrapped_view


@bp.route("/on_publish", methods=("POST", ))
@check_stream_secret
def on_publish():
    channel = Channel.query.filter_by(stream_key=request.form["name"]).first()
    if not channel:
        return "", 400
    channel.current_stream_id = str(uuid.uuid4())
    channel.live = True
    db.session.add(channel)
    db.session.commit()

    return redirect(current_app.config["RTMP_ROOT"] + "/streamrelay/"
                    + channel.current_stream_id, 302)


@bp.route("/on_publish_done", methods=("POST", ))
@check_stream_secret
def on_publish_done():
    channel = Channel.query.filter_by(stream_key=request.form["name"]).first()
    if not channel:
        return "", 400
    channel.current_stream_id = None
    channel.live = False
    db.session.add(channel)
    db.session.commit()

    return "", 200
